"""Mock package for Porringer tests.

This package contains mock implementations and utilities for testing Porringer plugins and environments.
"""

from porringer.test.mock.plugin_manager import MockPluginManager

__all__ = ['MockPluginManager']
